from typing import Dict, List, Type

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from typing_extensions import Any, TypedDict, TypeVar

from ..models.parameter_properties import ParameterProperties

T = TypeVar("T", bound="ParametersProperties")


class ParametersPropertiesDict(TypedDict):
    pass


@_attrs_define
class ParametersProperties:
    """ """

    additional_properties: Dict[str, "ParameterProperties"] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        field_dict: Dict[str, Any] = {}
        for prop_name, prop in self.additional_properties.items():
            field_dict[prop_name] = prop.to_dict()
        field_dict.update({})

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.parameter_properties import ParameterProperties

        d = src_dict.copy() if src_dict else {}
        parameters_properties = cls()

        additional_properties = {}
        for prop_name, prop_dict in d.items():
            additional_property = ParameterProperties.from_dict(prop_dict)

            additional_properties[prop_name] = additional_property

        parameters_properties.additional_properties = additional_properties
        return parameters_properties

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> "ParameterProperties":
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: "ParameterProperties") -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



""" Contains all the data models used in inputs/outputs """

from .api_response_validation_error import APIResponseValidationError
from .api_response_validation_error_code_enum import APIResponseValidationErrorCodeEnum
from .authentication_error import AuthenticationError
from .authentication_error_code_enum import AuthenticationErrorCodeEnum
from .blank_enum import BlankEnum
from .catch_all_error import CatchAllError
from .catch_all_error_code_enum import CatchAllErrorCodeEnum
from .chat_completion_input import ChatCompletionInput, ChatCompletionInputDict
from .chat_completion_input_response_format_type_0 import ChatCompletionInputResponseFormatType0
from .chat_completion_response import ChatCompletionResponse
from .conflict_error import ConflictError
from .conflict_error_code_enum import ConflictErrorCodeEnum
from .datapoint import Datapoint
from .delete_finetuning_job_request import DeleteFinetuningJobRequest, DeleteFinetuningJobRequestDict
from .document_chunks import DocumentChunks
from .document_input import DocumentInput, DocumentInputDict
from .document_output import DocumentOutput
from .document_type_enum import DocumentTypeEnum
from .embedding import Embedding
from .embeddings_input import EmbeddingsInput, EmbeddingsInputDict
from .embeddings_response import EmbeddingsResponse
from .encoding_format_enum import EncodingFormatEnum
from .enhancement import Enhancement
from .feedback_create import FeedbackCreate, FeedbackCreateDict
from .feedback_create_feedback import FeedbackCreateFeedback
from .fine_tuned_model_try_request import FineTunedModelTryRequest, FineTunedModelTryRequestDict
from .fine_tuned_model_try_response import FineTunedModelTryResponse
from .fine_tuning_job_create import FineTuningJobCreate, FineTuningJobCreateDict
from .fine_tuning_job_create_response import FineTuningJobCreateResponse
from .fine_tuning_job_details_request import FineTuningJobDetailsRequest, FineTuningJobDetailsRequestDict
from .fine_tuning_job_hyperparameters import FineTuningJobHyperparameters
from .fine_tuning_job_response import FineTuningJobResponse
from .fine_tuning_job_response_error import FineTuningJobResponseError
from .fine_tuning_job_response_evaluation_scores import FineTuningJobResponseEvaluationScores
from .fine_tuning_job_synthetic_datageneration_parameters import FineTuningJobSyntheticDatagenerationParameters
from .function import Function
from .init_page_data_request import InitPageDataRequest, InitPageDataRequestDict
from .init_page_data_response import InitPageDataResponse
from .message import Message
from .message_content_type_1_item import MessageContentType1Item
from .message_content_type_1_item_image_url import MessageContentType1ItemImageUrl
from .message_content_type_1_item_type import MessageContentType1ItemType
from .message_params import MessageParams
from .message_role_enum import MessageRoleEnum
from .messages import Messages
from .messages_role_enum import MessagesRoleEnum
from .model import Model
from .model_not_found_error import ModelNotFoundError
from .model_not_found_error_code_enum import ModelNotFoundErrorCodeEnum
from .model_provider_enum import ModelProviderEnum
from .model_type_enum import ModelTypeEnum
from .output_function import OutputFunction
from .output_function_arguments import OutputFunctionArguments
from .parameter_properties import ParameterProperties
from .parameters import Parameters
from .parameters_properties import ParametersProperties
from .permission_denied_error import PermissionDeniedError
from .permission_denied_error_code_enum import PermissionDeniedErrorCodeEnum
from .project import Project
from .provider_api_connection_error import ProviderAPIConnectionError
from .provider_api_connection_error_code_enum import ProviderAPIConnectionErrorCodeEnum
from .provider_api_status_error import ProviderAPIStatusError
from .provider_api_status_error_code_enum import ProviderAPIStatusErrorCodeEnum
from .provider_api_timeout_error import ProviderAPITimeoutError
from .provider_api_timeout_error_code_enum import ProviderAPITimeoutErrorCodeEnum
from .provider_internal_server_error import ProviderInternalServerError
from .provider_internal_server_error_code_enum import ProviderInternalServerErrorCodeEnum
from .provider_not_found_error import ProviderNotFoundError
from .provider_not_found_error_code_enum import ProviderNotFoundErrorCodeEnum
from .rate_limit_error import RateLimitError
from .rate_limit_error_code_enum import RateLimitErrorCodeEnum
from .repository import Repository, RepositoryDict
from .response_choice import ResponseChoice
from .status_enum import StatusEnum
from .tool import Tool
from .tool_call import ToolCall
from .trace_feedback import TraceFeedback
from .trace_list import TraceList
from .trace_retrieve import TraceRetrieve
from .trace_retrieve_document_chunk import TraceRetrieveDocumentChunk
from .type_enum import TypeEnum
from .unprocessable_entity_error import UnprocessableEntityError
from .unprocessable_entity_error_code_enum import UnprocessableEntityErrorCodeEnum
from .usage import Usage
from .v1_finetuned_model_try_create_response_404 import V1FinetunedModelTryCreateResponse404
from .v1_finetuning_job_details_create_response_404 import V1FinetuningJobDetailsCreateResponse404
from .v1_traces_list_admin_filter import V1TracesListAdminFilter
from .v1_traces_list_date_filter import V1TracesListDateFilter
from .validation_detail import ValidationDetail
from .validation_detail_error_messages_item import ValidationDetailErrorMessagesItem
from .validation_error import ValidationError
from .validation_error_code_enum import ValidationErrorCodeEnum
from .validation_error_details import ValidationErrorDetails

__all__ = (
    "APIResponseValidationError",
    "APIResponseValidationErrorCodeEnum",
    "AuthenticationError",
    "AuthenticationErrorCodeEnum",
    "BlankEnum",
    "CatchAllError",
    "CatchAllErrorCodeEnum",
    "ChatCompletionInput",
    "ChatCompletionInputResponseFormatType0",
    "ChatCompletionResponse",
    "ConflictError",
    "ConflictErrorCodeEnum",
    "Datapoint",
    "DeleteFinetuningJobRequest",
    "DocumentChunks",
    "DocumentInput",
    "DocumentOutput",
    "DocumentTypeEnum",
    "Embedding",
    "EmbeddingsInput",
    "EmbeddingsResponse",
    "EncodingFormatEnum",
    "Enhancement",
    "FeedbackCreate",
    "FeedbackCreateFeedback",
    "FineTunedModelTryRequest",
    "FineTunedModelTryResponse",
    "FineTuningJobCreate",
    "FineTuningJobCreateResponse",
    "FineTuningJobDetailsRequest",
    "FineTuningJobHyperparameters",
    "FineTuningJobResponse",
    "FineTuningJobResponseError",
    "FineTuningJobResponseEvaluationScores",
    "FineTuningJobSyntheticDatagenerationParameters",
    "Function",
    "InitPageDataRequest",
    "InitPageDataResponse",
    "Message",
    "MessageContentType1Item",
    "MessageContentType1ItemImageUrl",
    "MessageContentType1ItemType",
    "MessageParams",
    "MessageRoleEnum",
    "Messages",
    "MessagesRoleEnum",
    "Model",
    "ModelNotFoundError",
    "ModelNotFoundErrorCodeEnum",
    "ModelProviderEnum",
    "ModelTypeEnum",
    "OutputFunction",
    "OutputFunctionArguments",
    "ParameterProperties",
    "Parameters",
    "ParametersProperties",
    "PermissionDeniedError",
    "PermissionDeniedErrorCodeEnum",
    "Project",
    "ProviderAPIConnectionError",
    "ProviderAPIConnectionErrorCodeEnum",
    "ProviderAPIStatusError",
    "ProviderAPIStatusErrorCodeEnum",
    "ProviderAPITimeoutError",
    "ProviderAPITimeoutErrorCodeEnum",
    "ProviderInternalServerError",
    "ProviderInternalServerErrorCodeEnum",
    "ProviderNotFoundError",
    "ProviderNotFoundErrorCodeEnum",
    "RateLimitError",
    "RateLimitErrorCodeEnum",
    "Repository",
    "ResponseChoice",
    "StatusEnum",
    "Tool",
    "ToolCall",
    "TraceFeedback",
    "TraceList",
    "TraceRetrieve",
    "TraceRetrieveDocumentChunk",
    "TypeEnum",
    "UnprocessableEntityError",
    "UnprocessableEntityErrorCodeEnum",
    "Usage",
    "V1FinetunedModelTryCreateResponse404",
    "V1FinetuningJobDetailsCreateResponse404",
    "V1TracesListAdminFilter",
    "V1TracesListDateFilter",
    "ValidationDetail",
    "ValidationDetailErrorMessagesItem",
    "ValidationError",
    "ValidationErrorCodeEnum",
    "ValidationErrorDetails",
    "RepositoryDict",
    "RepositoryDict",
    "RepositoryDict",
    "DocumentInputDict",
    "ChatCompletionInputDict",
    "ChatCompletionInputDict",
    "ChatCompletionInputDict",
    "FineTuningJobCreateDict",
    "FineTuningJobCreateDict",
    "FineTuningJobCreateDict",
    "DeleteFinetuningJobRequestDict",
    "DeleteFinetuningJobRequestDict",
    "DeleteFinetuningJobRequestDict",
    "FineTunedModelTryRequestDict",
    "FineTunedModelTryRequestDict",
    "FineTunedModelTryRequestDict",
    "FineTuningJobDetailsRequestDict",
    "FineTuningJobDetailsRequestDict",
    "FineTuningJobDetailsRequestDict",
    "InitPageDataRequestDict",
    "InitPageDataRequestDict",
    "InitPageDataRequestDict",
    "EmbeddingsInputDict",
    "EmbeddingsInputDict",
    "EmbeddingsInputDict",
    "FeedbackCreateDict",
    "FeedbackCreateDict",
    "FeedbackCreateDict",
)



from typing import Dict, List, Type, Union, cast

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from typing_extensions import Any, NotRequired, TypedDict, TypeVar

from ..types import UNSET, Unset

T = TypeVar("T", bound="TraceRetrieveDocumentChunk")


class TraceRetrieveDocumentChunkDict(TypedDict):
    document_id: int
    content: NotRequired[Union[None, Unset, str]]
    pass


@_attrs_define
class TraceRetrieveDocumentChunk:
    """
    Attributes:
        document_id (int):
        content (Union[None, Unset, str]):
    """

    document_id: int
    content: Union[None, Unset, str] = UNSET

    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        document_id = self.document_id

        content: Union[None, Unset, str]
        if isinstance(self.content, Unset):
            content = UNSET
        else:
            content = self.content

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "document_id": document_id,
            }
        )
        if content is not UNSET:
            field_dict["content"] = content

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy() if src_dict else {}
        document_id = d.pop("document_id")

        def _parse_content(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        content = _parse_content(d.pop("content", UNSET))

        trace_retrieve_document_chunk = cls(
            document_id=document_id,
            content=content,
        )

        trace_retrieve_document_chunk.additional_properties = d
        return trace_retrieve_document_chunk

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
